%include common-macros.specinclude

Summary: PCM audio player for Linux and compatible OSes
Name: lsb-alsaplayer
Version: 0.99.80 
Release: 13.lsb5
Vendor: Linux Foundation
Packager: LSB project team <lsb-discuss@linuxfoundation.org>
License: GPL
Group: Appbat/text tools
BuildRoot: %{_tmppath}/%{name}-root
AutoReqProv: no
Requires: lsb >= 5.0
BuildRequires: lsb-build-libbat-%{appbatversion}
BuildRequires: lsb-build-cc

Source0: http://www.alsaplayer.org/alsaplayer-%{version}.tar.bz2
Source1: alsaplayer.png
Patch0: alsaplayer-%{version}.patch
Patch1: alsaplayer-%{version}.lsb5.patch

%description
LSB conforming version of alsaplayer.
AlsaPlayer is a new PCM player developed on the Linux Operating System. Since
the first public beta release it support has been added for various other
Operating Systems (mostly Unix variants). AlsaPlayer was written in the first
place to excercise the new ALSA (Advanced Linux Sound Architecture) driver and
library system. 

%prep
%setup -q -n alsaplayer-%{version}
%patch0 -p0 -b .lsbcc
%patch1 -p0 -b .lsb5

%build
# common environment settings
export LSBCC_LSBVERSION=%{appbatversion}
%define prefix /opt/lsb
%define app_prefix %{prefix}/appbat
%define bindir %{app_prefix}/bin
%define sharedir %{app_prefix}/share
%define mandir %{app_prefix}/man

%ifarch s390x ppc64 x86_64
%define lib lib64
%else
%define lib lib
%endif

# need to be able to align with the LSB/libbat version we're built for
export CC="lsbcc -L/opt/lsb/libbat/%{appbatversion}/%{lib} -I/opt/lsb/libbat/%{appbatversion}/include"
export CXX="lsbc++ -L/opt/lsb/libbat/%{appbatversion}/%{lib} -I/opt/lsb/libbat/%{appbatversion}/include"
%define libdir %{prefix}/%{lib}-%{appbatversion}
export PKG_CONFIG_PATH=%{libdir}/pkgconfig:/opt/lsb/libbat/%{appbatversion}/%{lib}/pkgconfig
export PATH=/opt/lsb/libbat/%{appbatversion}/bin:${PATH}

# disable CDDA support - wants kernel header stuff
export ac_cv_header_linux_cdrom_h=no

# alsa detection fails, no version.h in LSB
export have_alsa_final=yes

export ALSA_LIB=-lasound

# alsa detection fails, we don't set SND_LIB_*
sed -i 's|have_alsa_final=no|have_alsa_final=yes|g' configure

# looks for deprecated header 
sed -i 's|sys/asound|alsa/asound|g' configure

./configure \
	--prefix=%{app_prefix} \
	--disable-esd \
	--disable-flac \
	--disable-jack \
	--disable-mad \
	--disable-mikmod \
	--disable-nas \
	--disable-nls \
	--disable-oggflac \
	--disable-oggvorbis \
	--disable-oss \
	--disable-sgi \
	--disable-sparc

%install
rm -rf %{buildroot}

install -d %{buildroot}%{app_prefix}
make prefix=%{buildroot}%{app_prefix} install

# drop the headers and other devel stuff
rm -fr %{buildroot}%{app_prefix}/include
rm -fr %{buildroot}%{app_prefix}/lib/pkgconfig
find %{buildroot}%{app_prefix} -name "*.la" | xargs rm -f

# and the docs
rm -fr %{buildroot}%{sharedir}/doc/alsaplayer

# other packages provide this
rm -fr %{buildroot}%{app_prefix}/share/locale/locale.alias

# rename our desktop file
mv %{buildroot}%{app_prefix}/share/applications/alsaplayer.desktop %{buildroot}%{app_prefix}/share/applications/lsb-alsaplayer.desktop

# install an icon
install -d %{buildroot}%{app_prefix}/share/icons/hicolor/16x16/apps
cp %{SOURCE1} %{buildroot}%{app_prefix}/share/icons/hicolor/16x16/apps

# make a README about the patch
install -d %{buildroot}%{sharedir}/doc
COUNT=`grep -n '\-\-\-' %{PATCH0} | head -1 | awk -F\: '{print $1}'`
COUNT=`expr $COUNT - 1`
head -"$COUNT" %{PATCH0} > %{buildroot}%{sharedir}/doc/README.LSB.alsaplayer.build.patches 

# shows up in some builds? we don't need it
if [ -f %{buildroot}%{app_prefix}/lib/alsaplayer/input/libsndfile_in.so ];then
  rm -f %{buildroot}%{app_prefix}/lib/alsaplayer/input/libsndfile_in.so
fi

%pre

%post
if [ -x /usr/bin/xdg-desktop-menu ];then
  xdg-desktop-menu install %{sharedir}/applications/lsb-alsaplayer.desktop
fi

%preun
if [ -x /usr/bin/xdg-desktop-menu ];then
  xdg-desktop-menu uninstall %{sharedir}/applications/lsb-player.desktop
fi

%postun

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%dir %{app_prefix}
%dir %{bindir}
%{bindir}/alsaplayer
%dir %{app_prefix}/lib
%dir %{app_prefix}/lib/alsaplayer
%dir %{app_prefix}/lib/alsaplayer/input
%{app_prefix}/lib/alsaplayer/input/libwav.so
%dir %{app_prefix}/lib/alsaplayer/interface
%{app_prefix}/lib/alsaplayer/interface/libdaemon_interface.so
%{app_prefix}/lib/alsaplayer/interface/libgtk2_interface.so
%{app_prefix}/lib/alsaplayer/interface/libtext_interface.so
%dir %{app_prefix}/lib/alsaplayer/output
%{app_prefix}/lib/alsaplayer/output/libalsa_out.so
%{app_prefix}/lib/alsaplayer/output/libnull_out.so
%dir %{app_prefix}/lib/alsaplayer/reader
%{app_prefix}/lib/alsaplayer/reader/libfile.so
%{app_prefix}/lib/alsaplayer/reader/libhttp.so
%dir %{app_prefix}/lib/alsaplayer/scopes2
%{app_prefix}/lib/alsaplayer/scopes2/libblurscope.so
%{app_prefix}/lib/alsaplayer/scopes2/liblevelmeter.so
%{app_prefix}/lib/alsaplayer/scopes2/liblogbarfft.so
%{app_prefix}/lib/alsaplayer/scopes2/libmonoscope.so
%{app_prefix}/lib/alsaplayer/scopes2/liboglspectrum.so
%{app_prefix}/lib/alsaplayer/scopes2/libspacescope.so
%{app_prefix}/lib/alsaplayer/scopes2/libsynaescope.so
%{app_prefix}/lib/libalsaplayer.so
%{app_prefix}/lib/libalsaplayer.so.0
%{app_prefix}/lib/libalsaplayer.so.0.0.2
%dir %{sharedir}
%dir %{sharedir}/applications
%{sharedir}/applications/lsb-alsaplayer.desktop
%dir %{sharedir}/doc
%doc %{sharedir}/doc/README.LSB.alsaplayer.build.patches
%dir %{sharedir}/icons
%dir %{sharedir}/icons/hicolor
%dir %{sharedir}/icons/hicolor/16x16
%dir %{sharedir}/icons/hicolor/16x16/apps
%{sharedir}/icons/hicolor/16x16/apps/alsaplayer.png
%dir %{sharedir}/man
%dir %{sharedir}/man/man1
%{sharedir}/man/man1/alsaplayer.1

%changelog
* Wed May 11 2011 Stew Benedict <stewb@linux-foundation.org>
- use spec file to build, drop nALFS

* Fri Feb 25 2011 Stew Benedict <stewb@linux-foundation.org>
- own the dirs we populate (bug 3195)
